@@ -1,5 +1,5 @@
 import os
-import shutil
+import sys
 import tarfile
 import tempfile
 import backstage
@@ -15,7 +15,14 @@ class Act():
         if not os.path.exists(self.acthome):
             print 'Act %s does not exist in venue %s' % (self.venue.VENUE_NAME, self.actname)
             raise
+        self.get_settings()
 
+    def get_settings(self):
+        syspath = sys.path
+        sys.path.insert(0,os.path.join(self.venue.VENUE_ROOT,'acts'))
+        exec('from %s import settings' % self.actname)
+        sys.path = syspath
+        self.settings = settings
 
 def new_act(venue, actname):
     """create a new Act within a backstage Venue"""
@@ -33,10 +40,10 @@ def new_act(venue, actname):
         print 'A folder named %s already exists under %s' % (actname, actsdir)
         return None
     os.mkdir(acthome)
-    act = Act(venue, actname)
-    copy_act_skel(act)
-    create_act_uwsgi_file(act)
+    copy_act_skel(venue, actsdir, actname)
+    create_act_uwsgi_file(venue, actsdir, actname)
 
+    act = Act(venue, actname)
     if act:
         s = 'created Backstage Act %s at %s' % (actname, acthome)
         print s
@@ -44,21 +51,22 @@ def new_act(venue, actname):
         print s
     return act
 
-def create_act_uwsgi_file(act):
+def create_act_uwsgi_file(venue, actsdir, actname):
     """create the uwsgi ini file for a (usually) new Act. This reads in backstage/conf/uwsgi.ini.src
     and substitutes values appropriately."""
     srcfile = os.path.join(os.path.dirname(backstage.__file__),'conf/uwsgi.ini.src')
     with open(srcfile,'r') as f:
         srcdata = f.read()
-    outfile = os.path.join(act.acthome,'uwsgi.ini')
+    outfile = os.path.join(actsdir, actname, 'uwsgi.ini')
     o = open(outfile,'w')
-    o.write(srcdata.format(VENUE_ROOT=act.venue.VENUE_ROOT, VENUE_NAME=act.venue.VENUE_NAME, ACT_NAME=act.actname))
+    o.write(srcdata.format(VENUE_ROOT=venue.VENUE_ROOT, VENUE_NAME=venue.VENUE_NAME, ACT_NAME=actname))
     o.close()
     return
 
-def copy_act_skel(act):
+def copy_act_skel(venue, actsdir, actname):
     """copy the skeleton files into the Act instance folder"""
     backstage_home = os.path.dirname(os.path.abspath(backstage.__file__))
+    act_home = os.path.join(actsdir, actname)
     act_skel = os.path.join(backstage_home,'skel/act')
     #recursive copy via tar
     tmpfile = tempfile.NamedTemporaryFile()
@@ -70,6 +78,6 @@ def copy_act_skel(act):
     os.chdir(cwd)
     tar_file.close()
     tar_file = tarfile.open(tmpfile.name,'r')
-    tar_file.extractall(act.acthome)
+    tar_file.extractall(act_home)
     tar_file.close()
     os.remove(tmpfile.name)
