@@ -11,7 +11,7 @@ sys.path.insert(0, VENUE_ROOT)
 sys.path.insert(1, VENUE_PATH)
 # Run Django.
 if __name__ == "__main__":
-    settings_module = "%s.venue_settings" % VENUE_DIRNAME
+    settings_module = "%s.settings" % VENUE_DIRNAME
     os.environ.setdefault("DJANGO_SETTINGS_MODULE", settings_module)
     from django.core.management import execute_from_command_line
     execute_from_command_line(sys.argv)
